![](https://github.com/Wh1isper/newbee/actions/workflows/python-package.yml/badge.svg)
![](https://img.shields.io/pypi/dm/newbee)
![](https://img.shields.io/github/last-commit/wh1isper/newbee)
![](https://img.shields.io/pypi/pyversions/newbee)
![](https://img.shields.io/github/license/wh1isper/newbee)
![](https://img.shields.io/github/v/release/wh1isper/newbee?logo=github)
![](https://img.shields.io/github/v/release/wh1isper/newbee?include_prereleases&label=pre-release&logo=github)


# newbee

## Install

`pip install newbee`

## Usage


## Develop

Install pre-commit before commit

```
pip install pre-commit
pre-commit install
```

Install package locally

```
pip install -e .[test]
```

Run unit-test before PR, **ensure that new features are covered by unit tests**

```
pytest -v
```
